#!/usr/bin/python3
from netgen.csg import *
import ngsolve

def refineMesh(mesh):
    for el in mesh.Elements():
        mesh.SetRefinementFlag(el, el.nr == 0)
    mesh.Refine()

def getMesh():
    geo = CSGeometry()
    for x in range(3):
        for z in range(2):
            geo.Add( OrthoBrick( Pnt(x,0,z), Pnt(x+1,1,z+1) ) )
    geo.Add( OrthoBrick( Pnt(2,1,0), Pnt(3,2,1) ) )
    geo.Add( OrthoBrick( Pnt(2,1,1), Pnt(3,2,2) ) )
    return ngsolve.Mesh(geo.GenerateMesh())

if __name__ == '__main__':
    # generate initial mesh and count number of elements
    mesh = getMesh()
    ne1 = mesh.ne 
    # refine only the first element and count new number of elements
    refineMesh(mesh)
    ne2 = mesh.ne
    # compate number of elements
    print('Initial mesh has %i elements' % ne1)
    print('New mesh has %i elements' % ne2)
    
